# pymsb *(M&L Modding fork)*
**pymsb** provides implementations for Nintendo's homemade MSBT and MSBF file formats. Features that are exclusive to games can be handled by implementing custom adapter classes.

**Although this fork is maintained by the Mario & Luigi Modding organization,** it contains no hardcoded M&L-specific code and is intended to act as a continuation of the original `pymsb`, which was archived.

## Setup
This library requires **Python 3.10** or newer.
